package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````"",```````!``````````+BA````
M`````````$``.``(`$``&0`8``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````.23````````Y),`````````
M``$```````$````&````,)L````````PFP$``````#";`0``````4`4`````
M``!X%0```````````0```````@````8```!`FP```````$";`0``````0)L!
M```````@`@```````"`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````PFP```````#";`0``````,)L!``````#0!```````
M`-`$`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`7(B)Y).PGXP?+W;97S_NOR_G&_D1````4`````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A0````40```%4```!:````6P``
M`&(```!C````9````&8```!G`````````&D```!J````:P```&T`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`(@<````````````````````````
M`P`5``"@`0```````````````````P``$@`````````````````````````9
M`P``$@````````````````````````"@`@``$@``````````````````````
M``#-`@``$@`````````````````````````A`P``$@``````````````````
M``````!T`@``$@`````````````````````````1````(```````````````
M``````````"N`@``$@````````````````````````!K`@``$@``````````
M``````````````#4`@``(@````````````````````````"9`@``$@``````
M``````````````````""`@``$@````````````````````````"T````$@``
M```````````````````````O`P``$0````````````````````````"#`0``
M$@````````````````````````#C`@``$@````````````````````````"$
M````$@`````````````````````````,`0``$@``````````````````````
M``!-`@``$@`````````````````````````_`@``$@``````````````````
M``````"J`0``$@`````````````````````````!`0``$0``````````````
M```````````J`@``$@````````````````````````!G`0``$@``````````
M``````````````#C````$0`````````````````````````U`0``$@``````
M``````````````````!-`P``$@`````````````````````````'`P``$@``
M``````````````````````"2`@``$@````````````````````````#"````
M$@````````````````````````"Q`0``$@`````````````````````````-
M`@``$@````````````````````````">`0``$@``````````````````````
M``#;`0``$@````````````````````````"*`@``$@``````````````````
M``````#&`@``$@````````````````````````!Y`@``$@``````````````
M```````````\`P``$@````````````````````````#O`0``$@``````````
M``````````````!#`0``$@`````````````````````````M````(```````
M``````````````````")`P``$0````````````````````````!J`P``(0``
M```````````````````````V`P``$@````````````````````````"_`@``
M$@````````````````````````"\`0``$0````````````````````````!D
M````$@````````````````````````!;`P``$@``````````````````````
M``!:`@``$@`````````````````````````(!```$@``````````````````
M```````D`@``$@````````````````````````"3````$@``````````````
M``````````"?````$@````````````````````````!<`0``$@``````````
M``````````````#U`@``$@`````````````````````````B`0``$@``````
M```````````````````1`0``$@````````````````````````!6````$@``
M``````````````````````!A`@``$@`````````````````````````6`0``
M$@````````````````````````"3`0``$@````````````````````````#P
M````$@`````````````````````````X`@``$@``````````````````````
M``!U`0``$@````````````````````````!S````$@``````````````````
M```````5`@``$@````````````````````````"G`@``$@``````````````
M``````````!I`P``$0````````````````````````!K`P``$0``````````
M``````````````#U`0``$@````````````````````````#4````$@``````
M``````````````````!3`0``$@````````````````````````"X`@``$@``
M```````````````````````\````(`````````````````````````#\`0``
M$@````````````````````````!&`@``$@````````````````````````!5
M`P``$@````````````````````````"]`P``$``6`*BP`0``````````````
M```1!```$@`-`&A2````````@`````````#?`P``$@`.`'Q3````````````
M```````V!```$@`-`+A$````````A`D````````4`P``$@`-`,`@````````
M2`(```````#E`P``$@`-`+`]````````!`````````"N`P``$``6`("@`0``
M``````````````"D!```$@`-`+@]````````,`(```````">!```$@`+`(@<
M``````````````````#1!```$@`-`$!.````````*`0```````"B`P``$``6
M`("@`0`````````````````=!```$@`-`.@_````````+`````````!0!```
M$0`/`)!3````````!`````````#0`P``$``6`*BP`0````````````````#(
M`P``$``6`*BP`0````````````````"<!```$@`-`$`\````````.```````
M``"Q!```$@`-`+!#````````!`$```````##!```$@`-``!#````````B```
M``````!#!```$``5``"@`0`````````````````J!```$@`-`!A`````````
M'`$```````";`P``$``5`("@`0````````````````"%!```$0`5`'B@`0``
M````"`````````#5`P``$@`-`'A3````````!`````````!U!```$@`-`/A2
M````````@`````````!)!```$@`-``@C``````````````````!%!```(``5
M``"@`0````````````````#V`P``$@`-`(A#````````*`````````"\`P``
M$``6`*BP`0````````````````!?!```$@`-`-`\````````W`````````"/
M!```$@`-`#A!````````Q`$`````````;&EB<&5R;"YS;RXU+C(V`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?
M,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F
M971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O
M+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`')M9&ER`%]?<W1R;F-P
M>5]C:&L`<W1R8VAR`&=E='!I9`!U;FQI;FL`7U]M96UC<'E?8VAK`'-T<F-M
M<`!R96%D9&ER-C0`<F5A9&QI;FL`97AI=`!C;&]S961I<@!O<&5N9&ER`')E
M86QL;V,`;65M<V5T`&=E='5I9`!S=')T;VL`;65M8VAR`%]?>'-T870V-`!S
M=')S='(`86-C97-S`'-T<F1U<`!S=')L96X`7U]C>&%?9FEN86QI>F4`7U]R
M96=I<W1E<E]A=&9O<FL`7U]L>'-T870V-`!M96UC<'D`7U]L:6)C7W-T87)T
M7VUA:6X`;65M;6]V90!?7W-P<FEN=&9?8VAK`'-T9&5R<@!A8F]R=`!?7W-T
M86-K7V-H:U]F86EL`'-T<FYC;7``;6MD:7(`7U]F<')I;G1F7V-H:P!?7V5N
M=FER;VX`;&0M;&EN=7@M86%R8V@V-"YS;RXQ`%]?<W1A8VM?8VAK7V=U87)D
M`%]E9&%T80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?
M`%]?96YD7U\`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE
M8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R
M=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C
M7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?
M9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U])
M;G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P`````````"``(``@`"``(`
M`@````(``@`"``(``@````(````"```````"``(``@````(``````````@`"
M``(```````,````#``(``@`"``(``P``````!``"``(``@```````@`"``(`
M`@`````````"`````@````(``````````@```````P`"``(``@`#```````"
M`````P`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$````!``$`<P,``!`````@````EY&6
M!@``!`#G!`````````$``0#+`0``$````"````"7D98&```#`.<$````````
M`0`!`!H"```0`````````)>1E@8```(`YP0````````PFP$```````,$````
M````""0````````XFP$```````,$````````P",```````"`GP$```````,$
M````````>%,```````#0GP$```````,$````````^%(```````#@GP$`````
M``,$````````P"`````````(H`$```````,$````````"*`!```````8H`$`
M``````,$````````H%<````````@H`$```````,$````````T%,````````P
MH`$```````,$````````,%4````````XH`$```````,$````````@%<`````
M``!`H`$```````,$````````B%<```````!(H`$```````,$````````D%<`
M``````!0H`$```````,$````````F%<```````!@H`$```````,$````````
M:%<```````!HH`$```````,$````````<%<```````!XH`$```````,$````
M````J%<```````"(GP$```````$$```)``````````````"0GP$```````$$
M```,``````````````"8GP$```````$$```0``````````````"@GP$`````
M``$$```1``````````````"HGP$```````$$```8``````````````"PGP$`
M``````$$```;``````````````"XGP$```````$$```K``````````````#`
MGP$```````$$```L``````````````#(GP$```````$$```P````````````
M``#8GP$```````$$```Z``````````````#HGP$```````$$``!#````````
M``````#PGP$```````$$``!'``````````````#XGP$```````$$``!,````
M``````````!XG0$```````($```#``````````````"`G0$```````($```$
M``````````````"(G0$```````($```%``````````````"0G0$```````($
M```&``````````````"8G0$```````($```'``````````````"@G0$`````
M``($```(``````````````"HG0$```````($```*``````````````"PG0$`
M``````($```+``````````````"XG0$```````($```,``````````````#`
MG0$```````($```-``````````````#(G0$```````($```.````````````
M``#0G0$```````($```/``````````````#8G0$```````($```2````````
M``````#@G0$```````($```3``````````````#HG0$```````($```4````
M``````````#PG0$```````($```5``````````````#XG0$```````($```6
M````````````````G@$```````($```7```````````````(G@$```````($
M```9```````````````0G@$```````($```:```````````````8G@$`````
M``($```<```````````````@G@$```````($```=```````````````HG@$`
M``````($```>```````````````PG@$```````($```?```````````````X
MG@$```````($```@``````````````!`G@$```````($```A````````````
M``!(G@$```````($```B``````````````!0G@$```````($```C````````
M``````!8G@$```````($```D``````````````!@G@$```````($```E````
M``````````!HG@$```````($```F``````````````!PG@$```````($```G
M``````````````!XG@$```````($```H``````````````"`G@$```````($
M```I``````````````"(G@$```````($```J``````````````"0G@$`````
M``($```K``````````````"8G@$```````($```N``````````````"@G@$`
M``````($```O``````````````"HG@$```````($```Q``````````````"P
MG@$```````($```R``````````````"XG@$```````($```S````````````
M``#`G@$```````($```T``````````````#(G@$```````($```U````````
M``````#0G@$```````($```V``````````````#8G@$```````($```W````
M``````````#@G@$```````($```X``````````````#HG@$```````($```Y
M``````````````#PG@$```````($```[``````````````#XG@$```````($
M```\````````````````GP$```````($```]```````````````(GP$`````
M``($```^```````````````0GP$```````($```_```````````````8GP$`
M``````($``!````````````````@GP$```````($``!!```````````````H
MGP$```````($``!"```````````````PGP$```````($``!$````````````
M```XGP$```````($``!%``````````````!`GP$```````($``!(````````
M``````!(GP$```````($``!)``````````````!0GP$```````($``!*````
M``````````!8GP$```````($``!+``````````````!@GP$```````($``!-
M``````````````!HGP$```````($``!.``````````````!PGP$```````($
M``!/``````````````#]>[^I_0,`D:P!`)3]>\&HP`-?U@````#P>[^IT```
MD!&Z1OD0PC61(`(?UA\@`]4?(`/5'R`#U=```)`1OD;Y$.(UD2`"'];0``"0
M$<)&^1`"-I$@`A_6T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(VD2`"'];0
M``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y$*(VD2`"
M'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1XD;Y$`(W
MD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM```)`1[D;Y
M$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?UM```)`1
M^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1(`(?UM``
M`)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D08CB1(`(?
MUM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:1_D0PCB1
M(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```D!$F1_D0
M(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6T```D!$R
M1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@`A_6T```
MD!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B.I$@`A_6
MT```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'^1"".I$@
M`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0$5Y'^1#B
M.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0``"0$6I'
M^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"'];0``"0
M$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([D2`"'];0
M``"0$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y$$(\D2`"
M']:P``#P$8Y'^1!B/)$@`A_6L```\!&21_D0@CR1(`(?UK```/`1ED?Y$*(\
MD2`"']:P``#P$9I'^1#"/)$@`A_6L```\!&>1_D0XCR1(`(?UK```/`1HD?Y
M$`(]D2`"']:P``#P$:9'^1`B/9$@`A_6L```\!&J1_D00CV1(`(?UK```/`1
MKD?Y$&(]D2`"']:P``#P$;)'^1""/9$@`A_6L```\!&V1_D0HCV1(`(?UK``
M`/`1ND?Y$,(]D2`"'];]>[FI_0,`D?-3`:FS``#PM```\&/B1_FBAP2IHB,!
MD60`0/FD-P#Y!`"`TJ!?`+FA0P&1H',!D8K__Y>@``#PH@``\`#T1_E"[$?Y
MX0,"JG8,`)2@``#P`-A'^0``0#E@`0`U2___E\(``)!`4`#Y0`X`M+0``/`6
M__^7@-9'^0``0+E/__^7'X0D.9361_F``D"Y2___EP'H4SDA`!\R`>@3.8`"
M0+E&__^7`NA3.:%?0+D#`/R20@``,@+H$SDA%``1M5L"J;<;`/DA?$"3/P`#
MZV@*`%0@\'W3-?__EZ4K0/G"``"0U```D(0B`I%'/$#Y`P``\*@`0/D!``#P
M8V`=D2&`'9&&`(!2HE]`N0@,`*D'!`&I7P0`<88$`+F`!`#Y30$`5"$`@-+F
M`("2)!``$:-X8?@A!`"1Q,PDBU\``6L#:"3X3/__5$40`!&6(@*1XP,`J@$`
M`+`%S"6+!`"`TL`.0/E"#``1(>`QD;^`'_AO__^7]0,`*J`#`#26(@*1MY,!
MD<`.0/GI_O^7````\.$#%ZH``!.1JP0`E``"`+24(@*1@`Y`^<W^_Y=4__^7
M<^)'^>`#%2JB-T#Y80)`^4$``<IA`P"UM5M"J?-30:FW&T#Y_7O'J,`#7];`
M"D#YX```M/`+`)3N__\7P`Y`^6___Y?U`P`JX?__%P```/#A`Q>J`"`1D8\$
M`)3`"@#Y@/S_M.0+`)3B__\7H0``\````/``0!V1(>1'^23__Y?S_O^7M5L"
MJ2``@%*W&P#Y@_[_EQT`@-(>`(#2Y0,`JN$#0/GB(P"1Y@,`D:```/``\$?Y
MHP``\&/H1_FD``#PA,!'^;K^_Y?Q_O^7H```\`#<1_E```"TZ?[_%\`#7]8`
M````P```D````I'!``"0(0`"D3\``.N@``!4H0``\"'$1_E!``"T(``?UL`#
M7]8?(`/5P```D````I'!``"0(0`"D2$``,LA_$.3(?Q!BR'\09.A``"TH@``
M\$+\1_E"``"T0``?UL`#7];]>[ZI_0,`D?,+`/G3``"08`)".4`!`#6@``#P
M`,A'^8```+3```"0``1`^57^_Y?:__^7(`"`4F`"`CGS"T#Y_7O"J,`#7];@
M__\7`````/^#"M&H``#P!.``D0G@`9']>P"I_0,`D:)C`)$!X4?Y1R``D2,`
M0/FC3P'Y`P"`TH$`0+F#A$#X(0C`6N&`'_B?``GK8?Q@TV;\:-/&''B2)=QX
MTR$<"%.E''"2P^!#JB$`!:HA``.JX00!^"'^_U1&``B1'R`#U44`0/E"(`"1
M0P1`^40<0/E!,$#Y8P`%RE\`!NLA``3*(0`#RB/\7]-A!`&J(7Q`DD$\`/EA
M_O]4!1!`J8``9YX&'$&IX0!GGL(`9YZ!_$+3(7@$JJ+\6]-`'&$N+7Q`DJ$!
M9YY"%`6JJ[]!J2,SC](,`&:>H`!GGD-0J_()$$#Y(!QB+FL!`XNN_$+3[P$#
MBX)!(HO.>06J0@`+BR$`#LH*`&:>0@`)"ZL70/DA``**3/Q;TR$`#<J,%0*J
M(0`&BTH!!XO0?4"22@$/BXP!"@M*_$+30GD"JFH!`XN+_5O3(0`*BVL5#*K*
M`0+*COU"TVL!`0M*`0R*S'D,JJ$[0ZE*`1#*2@$-BVW]6],A``.+K14+JDH!
M`8M!``S*J@$*"T]\0)(A``N*8OU"TR$`#\I+>`NJS@$#BR$`$(M-_5O3@@$+
MRJT5"JHA``Z+H0$!"Y!]0)*N(T#Y0@`*BDW]0M-"`!#*K7D*JD(`#XO*`0.+
M+OQ;T\X5`:I"``J+:@$-RL(!`@MO?4"2KB=`^4H!`8HL_$+32@$/RHQY`:I*
M`1"+P0$#BT[\6]-*`0&+SA4"JJ$!#,K*`0H+K7U`DJXK0/DA``**2_Q"TR$`
M#<IK>0*J(0`/B\(!`XM._5O3SA4*JB$``HN"`0O*P0$!"X]]0)*N+T#Y0@`*
MBDS]0M-"``_*C'D*JD(`#8O*`0.++?Q;TT(`"HNM%0&J:@$,RJ(!`@MN?4"2
MK3-`^4H!`8HK_$+32@$.RFMY`:I*`0^+H0$#BTW\6].M%0*J2@$!BX$!"\JJ
M`0H+CWU`DJTW0/DA``**3/Q"TR$`#\J,>0*J(0`.BZ(!`XM-_5O3(0`"BZT5
M"JIB`0S*H0$!"VY]0)*M.T#Y0@`*BDO]0M-"``[*:WD*JD(`#XNJ`0.++?Q;
MTZT5`:I"``J+B@$+RJ(!`@N/?4"2K3]`^4H!`8HL_$+32@$/RHQY`:I*`0Z+
MH0$#BTW\6]-*`0&+K14"JF$!#,JJ`0H+;GU`DJU#0/DA``**2_Q"TR$`#LIK
M>0*J(0`/BZ(!`XN/?4"2(0`"BX(!"\I-_5O30@`*BJT5"JI"``_*H0$!"T(`
M#HNMNTBI3/U"TXQY"JIQ?4"2J@$#BRW\6].M%0&J0@`*BVH!#,JB`0(+2@$!
MBBW\0M-*`1'*K7D!JDH!#XO!`0.+2_Q;TTH!`8MK%0*J@0$-RFL!"@N0?4"2
MJKM)J2$``HHA`!#*3_Q"T^]Y`JI*`0.+(0`1BVS]6],A``J+C!4+JJH!#\J,
M`0$+L7U`DDH!"XI*`1'*C?U;T\X!`XM*`1"+8?U"TTH!#HLA>`NJJQ4,JFL!
M"@OB`0'*\'U`DD(`#(JM5T#Y0@`0RFK]6]-"`!&+K0$#BTH5"ZI"``V+C?U"
MTZUY#*I*0"J+3GU`DB]\0)(A``W*K%M`^2$`"XK"_5O3(0`/RD(4#JJ#`0.+
M(0`0BR$``XMC_4+3,D`BBV%X"ZJC`0'*4'Y`DF,`"DHJ=)W28P`/BP+^6].L
MOTNI*MNM\D(4$*K+_4+3C`$*BVMY#JIC``R+<4`BBR(`"\HN?D"20@`22D)`
M+8OM`0J+S/U;TT(`#8N,%0ZJ`_Y"TV-X$*I,0"R+8@$#RJW#3*F/?4"20@`1
M2D%`(8NB`0J+[?U;TR$``HNM%0^JPOU"TT)X#JHM0"V+80`"RJY]0)(L``Q*
MBT$KBP$""HO,_5O3:P$!BXP5#JKA_4+3(7@/JK!O0/EL02R+2P`!RH]]0))M
M`0U*HT$CBPL""HOM_5O38P`+BZT5#ZK+_4+3:WD.JK!S0/EM0"V+(P`+RJY]
M0))L``Q*@D$BBP,""HO,_5O30@`#BXP5#JKC_4+38W@/JK!W0/E,0"R+8@$#
MRH]]0))-``U*H4$ABP(""HOM_5O3(0`"BZT5#ZK"_4+30G@.JK![0/DM0"V+
M80`"RJY]0)(L``Q*BT$KBP$""HO,_5O3:P$!BXP5#JKA_4+3(7@/JK!_0/EL
M02R+2P`!RH]]0))M`0U*HT$CBPL""HOM_5O38P`+BZT5#ZK+_4+3:WD.JK"#
M0/EM0"V+(P`+RJY]0))L``Q*@D$BBP,""HO,_5O30@`#BXP5#JKC_4+38W@/
MJK"'0/E,0"R+8@$#RH]]0))-``U*H4$ABP(""HOM_5O3(0`"BZT5#ZK"_4+3
M0G@.JK"+0/DM0"V+80`"RJY]0)(L``Q*BT$KBP$""HO,_5O3:P$!BXP5#JKA
M_4+3(7@/JK"/0/EL02R+2P`!RH]]0))M`0U*HT$CBPL""HOM_5O38P`+BZT5
M#ZK+_4+3:WD.JK"30/EM0"V+(P`+RJY]0))L``Q*@D$BBP,""HO,_5O30@`#
MBXP5#JKC_4+38W@/JK"70/E,0"R+8@$#RH]]0))-``U*H4$ABP(""HOM_5O3
M(0`"BZT5#ZK"_4+30G@.JK";0/DM0"V+80`"RJY]0)(L``Q*BT$KBP$""HO,
M_5O3:P$!BXP5#JKA_4+3(7@/JK"?0/EK02R+3``!RF]]0)*-`0U*HT$CBPP"
M"HOM_5O38P`,BZT5#ZK,_4+3C'D.JK"C0/EM0"V+(P`,RJY]0))K``M*8D$B
MBP,""HO+_5O30@`#BVL5#JKC_4+3;W@/JD)`*XN#`0_*2WQ`DF,`#4IA0"&+
MP_U"TVW]6]-C>`ZJKA4+JG%\0)*PMU2I$`(*BZH!"HLA`!"+P0$!"^X!`\K.
M`0)*8OU"TT)X"ZK,02R++OQ;TTU\0)**`0J+8P`"JLP5`:IC``&*KL-5J8P!
M"@LJ`@V**_Q"TV,`"JJ*FY?2:N.Q\F%Y`:K.`0J+8T`OBXO]6],O?$"28P`.
MBVL5#*I"``&J:P$#"T(`#(JC`0^*0@`#JH/]0M-C>`RJ$`(*BT(`$8ML_5O3
M;GQ`DD(`$(N,%0NJ(0`#JHP!`@LA``N*X@$.BK"W0/DA``*J8OU"TT)X"ZH0
M`@J+(0`-BXO]6]--?$"2(0`0BVL5#*IC``*J:P$!"V,`#(K!`0V*L+M`^6,`
M`:J!_4+3(7@,JA`""HMC``^+;/U;TR]\0))C`!"+C!4+JD(``:J,`0,+0@`+
MBJ,!#XJPOT#Y0@`#JF/]0M-C>`NJ$`(*BT(`#HN+_5O3;GQ`DD(`$(MK%0RJ
M(0`#JFL!`@LA``R*X@$.BK##0/DA``*J@OU"TT)X#*H0`@J+(0`-BVS]6]--
M?$"2(0`0BXP5"ZIC``*JC`$!"V,`"XK!`0V*L,=`^6,``:IA_4+3(7@+JA`"
M"HMC``^+B_U;TR]\0))C`!"+:Q4,JD(``:IK`0,+0@`,BJ,!#XJPRT#Y0@`#
MJH/]0M-C>`RJ$`(*BT(`#HML_5O3;GQ`DD(`$(N,%0NJ(0`#JHP!`@LA``N*
MX@$.BK#/0/DA``*J8OU"TT)X"ZH0`@J+(0`-BXO]6]--?$"2(0`0BVL5#*IC
M``*J:P$!"V,`#(K!`0V*L--`^6,``:J!_4+3(7@,JA`""HMC``^+;/U;TR]\
M0))C`!"+C!4+JD(``:J,`0,+0@`+BJ,!#XJPUT#Y0@`#JF/]0M-C>`NJ$`(*
MBT(`#HN+_5O3;GQ`DD(`$(MK%0RJ(0`#JFL!`@LA``R*X@$.BK#;0/DA``*J
M@OU"TT)X#*H0`@J+(0`-BVS]6]--?$"2(0`0BXP5"ZIC``*JC`$!"V,`"XK!
M`0V*L-]`^6,``:IA_4+3(7@+JA`""HMC``^+B_U;TR]\0))C`!"+:Q4,JD(`
M`:IK`0,+0@`,BJ,!#XJPXT#Y0@`#JH/]0M-C>`RJ$`(*BT(`#HML_5O3;GQ`
MDD(`$(N,%0NJ(0`#JHP!`@LA``N*X@$.BK#G0/DA``*J8OU"TT)X"ZH0`@J+
M(0`-BXO]6]--?$"2(0`0BVL5#*IC``*J:P$!"V,`#(K!`0V*L.M`^6,``:J!
M_4+3(7@,JA`""HMC``^+;_U;TRQ\0))C`!"+[Q4+JD(``:KO`0,+0@`+BJ,!
M#(JP[T#Y0@`#JF/]0M-C>`NJ$`(*BT(`#HON_5O3:WQ`DD(`$(O.%0^J(0`#
MJLX!`@N0`0N*(0`/BJ+S0/DA`!"J\/U"TT(`"HLA``V+S?U;TR$``HNM%0ZJ
M`GH/JJT!`0M/?$"28P`"JF$!#XIC``Z*L/=`^6,``:JA_5O3$`(*BV,`#(LL
M%`VJ8P`0B\']0M.P^T#Y(7@.JG)`+(M#?D"2+'Q`DD(``:KQ`0R*0@`-BF[\
M6]-"`!&J$`(*BT(`"XO*%0.J0@`0BZO]0M-10"J+;7D-JC!^0)(A``W*JO]`
M^2$`$DH._EO3PCJ8TD),N?+.%1"J2@$"BR$`#XLA``J+:OQ"TS)`+HM#>0.J
M3GY`DJL#0?FJ`0/*".%'^6$!`HM*`1%*R_U;TTH!#(MK%0ZJ2@$!BP'^0M.L
M!T'Y44$KBRIX$*HO?D"280`*RB$`$DJ,`0*+Z_U;TR%`+8MK%0^J(0`,B\W]
M0M.L"T'Y,$`KBZ%Y#JH.?D"230$!RJT!$4J,`0*+R_U;TZ-!(XMK%0ZJ8P`,
MB^W]0M.L#T'Y<4`KBZ-Y#ZHO?D"2+0`#RJT!$$J,`0*+Z_U;TZI!*HMK%0^J
M2@$,B\W]0M.L$T'Y4$$KBZIY#JH.?D"2;0`*RJT!$4J,`0*+R_U;TZ%!(8MK
M%0ZJ(0`,B^W]0M.L%T'Y,4`KBZ%Y#ZHO?D"230$!RJT!$$J,`0*+Z_U;TZ-!
M(XMK%0^J8P`,B\W]0M.L&T'Y<$`KBZ-Y#JH.?D"2+0`#RJT!$4J,`0*+R_U;
MTZI!*HMK%0ZJ2@$,B^W]0M.L'T'Y44$KBZIY#ZHO?D"2;0`*RJT!$$J,`0*+
MZ_U;TZ%!(8MK%0^J(0`,B\W]0M.L(T'Y,$`KBZ%Y#JH.?D"230$!RJT!$4J,
M`0*+R_U;TZ-!(XMK%0ZJ8P`,B^W]0M.L)T'Y<4`KBZ-Y#ZHO?D"2+0`#RJT!
M$$J,`0*+Z_U;TZI!*HMK%0^J2@$,B\W]0M.L*T'Y4$$KBZIY#JH.?D"2;0`*
MRJT!$4J,`0*+R_U;TZ%!(8MK%0ZJ(0`,B^W]0M.L+T'Y,4`KBZ%Y#ZHO?D"2
M30$!RJT!$$J,`0*+Z_U;TZ-!(XMK%0^J8P`,B\W]0M.L,T'Y<$`KBZ-Y#JH.
M?D"2+0`#RJT!$4J,`0*+R_U;TZI!*HMK%0ZJ2@$,B^W]0M.L-T'Y44$KBZIY
M#ZHO?D"2;0`*RJT!$$J,`0*+Z_U;TZ%!(8MK%0^J(0`,B\S]0M.M.T'Y,$`K
MBX%Y#JH+?D"23@$!RLX!$4JM`0*+;/U;T\-!(XN,%0NJ8P`-B^[]0M.M/T'Y
M<4`LB\-Y#ZHL?D"2+P`#RN\!$$JM`0*+COU;T^I!*HO.%0RJ2@$-BV_]0M.M
M0T'Y4$$NB^MY"ZH/?D"2;@`+RLX!$4JM`0*+ZOU;T\%!(8M*%0^J(0`-BXW]
M0M.N1T'YK'D,JB%`*HLM?$"2:@$,RDH!$$K.`0*+0T$CB_#]0M.J_5O38P`.
MBP]Z#ZI*%0VJ2@$#"ZY+0?F#`0_*A``*"V$``4K"`0*+*T`KBT/]6]-K`0*+
MH?U"TV(4"JHA>`VJ0@`+"R8`!@OG`0<+B0$)"T4`!0L%$`"I!AP!J0D0`/FA
M3T'Y``%`^2```,J```"U_7M`J?^#"I'``U_6;_K_E_U[O*G]`P"1\PL`^8`'
M`+2B``#0N!\`^4+X1_E8`$#Y.`<`M+43`/D5`(!2`@!`.5_T`'%$&$!Z80,`
M5!,#0/F3!0"TM`\`^;5^0).VWP*I]`,8JO<#`:KV`P"J'R`#U>`#$ZKB`Q6J
MX0,6JB?Z_Y>````U8&IU.!_T`'$@`@!4DXY`^//^_[6TUT&IMM]"J;@?0/G@
M`Q.J\PM`^?U[Q*C``U_6]0,`JJ(>0#A?]`!Q1!A`>J'__U2U`@!+X/__%Y0"
M&,NU!@"1<P(5BY3^0Y/T`@"YX`,3JK370:FVWT*IN!]`^?,+0/G]>\2HP`-?
MUK430/FX'T#YY___%Q,`@-+E__\7$P"`TK@?0/GB__\7_7N\J?T#`)'U6P*I
MM@``T/-3`:FS``#0]0,`JL#B1_ES^D?YM-,`D0$`0/FA'P#Y`0"`TN$#%*K@
M`Q6JK?__EP`"`+2C-X"Y8@)`^4`,`XL!!$#Y07@C^.'^_[0?(`/5`"``D0$$
M0/D!``#YH?__M>$#%*K@`Q6JGO__ET#^_[76XD?YH1]`^<`"0/D@``#*H```
MM?-30:GU6T*I_7O$J,`#7]8!^O^7_7NYJ?T#`)'S4P&I\P,!JO5;`JFU``#0
M]V,#J?0#`*JAXD?Y8`)`.2(`0/FB-P#Y`@"`TA_T`'%S%I.:X`,3JGSY_Y?V
M`P"JH9,!D>`#%*I^__^7``@`M/<#`*IU^?^7'P`6ZZ(&`%2X9X"YMP``T!CS
M?=.``D`Y'_0`<0080'J`#`!4X0,4JB`<0#@?]`!Q!!A`>J'__U0A`!3+(7Q`
MD_?Z1_G`"@"1```!B_8"0/F8^?^7P&HX^*`+`+2C9X"Y@`8`D>("0/F!`D`Y
M0GAC^#_T`'$D&$!Z00``.<```%0!%$`X01P`.#_T`'$D&$!Z@?__5$$$`)&@
M!X!20```.6`60#@@%``XP/__-0``@%*UXD?YHC=`^:$"0/E!``'*H0@`M?-3
M0:GU6T*I]V-#J?U[QZC``U_6``"`TA\@`]5A:F`XX6H@.``$`)&A__\U[___
M%[<``-"Y:P2INRL`^>#Z1_D8`$#Y``-`^6`%`+3A`QBJ``"`4@(``!3@`QDJ
M(HQ`^!D$`!&B__^U``P`$0!\?9.A``#P(HA`N6("`#4B`(!2(H@`N5KY_Y?[
M`P"JH`,`M#I_0)/A`QBJ6/-]T^(#&*H3^?^7X/I'^1L``/E:!P"1?WLZ^+EG
M`+FY:T2INRM`^:3__Q?A`P"JX`,8JGCY_Y?[`P"JX/I'^1L``/D[`0"T.G]`
MDUCS?=/Q__\7`0"`TJ/__Q<``H#2&0"`4MW__Q>Y:T2INRM`^0``@!*X__\7
MN6L$J;LK`/EQ^?^7_7NRJ?T#`)'S"P#YLP``T&'B1_DB`$#YHF\`^0(`@-+`
M``"TM`\`^?0#`*H!`$`Y00$`-;0/0/ESXD?YH6]`^6`"0/D@``#*H`D`M?,+
M0/G]>\ZHP`-?UK87`/D!^?^7]@,`JN`&`+2W8P.I%P``T!@``-"Z)P#Y]T(/
MD1AC#Y&Z8P&1M1,`^>`#%JJ1^?^7X`4`M!5,`)'A`Q>JX`,5JFCY_Y<@__\T
MX0,8JN`#%:ID^?^7H/[_-+DC`/G@`Q2JS/C_E_D#`*K@`Q6JR?C_EP``&0L`
M"``1`'Q`D_WX_Y?E`Q6JY`,4J@,``-!C@`^1^0,`J@(`@)(A`(!2P?C_E^(#
M&JKA`QFJ``"`4L7X_Y<?!``QH```5*!K0+D`#!02'Q!`<6`"`%3@`QFJG?G_
ME^`#&:I?^?^7N2-`^=/__Q>T#T#YMA=`^;S__Q?@`Q:J&/G_E^`#%*I"^?^7
MM-=!J;;?0JFX'T#YNB=`^;/__Q?@`QFJH___E^[__Q>TUP&IMM\"J;CG`ZFZ
M)P#Y#?G_E_U[M:GA`P"J_0,`D?-3`:FS``#0]`,`JJ*C`)%CXD?Y``"`4F0`
M0/FD5P#Y!`"`TCCY_Y?@`0`UH3M`N0(`E%(A#!02/Q!`<2000GI@`0!4<^)'
M^:)70/EA`D#Y00`!RH$!`+7S4T&I_7O+J,`#7]8``(!2]___%T$`@%+@`Q2J
M`/G_EQ\``''@%Y\:\?__%^CX_Y<?(`/5$`J"TO]C,,OB_X'2_7L`J?T#`)'S
M"P#YLP``T/5;`JFU(P&1]V,#J?8#`*ICXD?Y]P,!J@```-#A`Q6J9`!`^:0G
M"/D$`(#2`*`/D6_X_Y<?``!Q304`5`($`%&T#P#YH0``T*/*8C@AU$?Y.`!`
MN6,#`#3B`P`J5'Q`D^$%@%+B`Q2JX`,5JB3Y_Y>@`@"TX`,8*K'X_Y?C`Q2J
MX@,5JN$#%JHE^?^7M`]`^7/B1_FA)TCY8`)`^2```,J``@"U_7M`J1`*@M+S
M"T#Y]5M"J?=C0ZG_8S"+P`-?UN+\_S6T#T#YX`,8*ISX_Y?B`Q>JX0,6JGGX
M_Y?M__\7H```T`#41_D8`$"Y]___%[0/`/FB^/^7'R`#U?U[OZF@``#0_0,`
MD0#41_D``$"YB_C_EZ(``-`#``#0_7O!J`$``-!"T$?Y8V`.D2'@#Y''^/\7
M_7N^J?T#`)'S"P#YLP``T'/61_E@`D"Y?/C_E^O__Y=@`D"Y>?C_E_,+0/G]
M>\*H!```T(0@'9$"``"P`0``T`4`@%+C`P2J0@`YD2%@$)'.^/\7'R`#U1`*
MA-+_8S#+``B"TOU[`*G]`P"1\U,!J;0``-#U6P*IM@,`BX#B1_FSXP"1`0!`
M^:$G$/D!`(#2+OC_E^0#`"H%``#0`P``T*7`$)%CX!"1(@""TB$`@%+@`Q.J
M]??_EP(`@M+A`Q:JX`,3JOWW_Y<``_@W\P,`J@`$`!$`?$"3(/C_E_4#`*K`
M``"T<WY`D^$#%JKB`Q.JUO?_E[]J,SB4XD?YX`,5JJ(G4/F!`D#Y00`!RB$!
M`+7]>T"I$`J$TO-30:GU6T*I_V,PB\`#7]85`(#2\___%T;X_Y<?(`/5R/__
M%Q\@`]40'H+2_V,PR_U[`*G]`P"1]QL`^;<``-#S4P&I]`,`JO43`/GS`P&J
MXN)'^:&3`9$```#0`"`1D4,`0/FC=PCY`P"`TL/]_Y?U`P"JX06`4N`#%*J!
M^/^70`(`M````-#A`Q2J`&`1D2C^_Y?@`Q2J]^)'^:)W2/GA`D#Y00`!R@$-
M`+7]>T"I$!Z"TO-30:GU$T#Y]QM`^?]C,(O``U_6N!\`^>`#%*JZ)P#YH_?_
MEQ@``-#Z`P`J`:,1D>`#$ZJ:]_^7\P,`JF`*`+2V%P#YMJ,#D;DC`/D9``#0
MNRL`^3G#$9$;``#0>T,/D1\@`]5@`D`Y0`8`-+4``+3A`Q.JX`,5JB'X_Y>`
M!``TX`,3JHKW_Y?A`P`J8,(@BP#P7S@?O`!QX0``5"$$`%%@PB&+?\HA.`#P
M7S@?O`!Q8/__5$`'`!$!``$+/_P_<0P#`%0#``#0Y@,4JN4#&:KD`Q.J8^`1
MD0(`@M(A`(!2X`,6JG;W_Y>BHP&1X0,6J@``@%)Z]_^7H```-:![0+D`#!02
M'R!`<4`"`%0!HQ&1``"`TF+W_Y?S`P"J0/K_M;870/FXYT.INN]$J:G__Q>U
M``"TX0,;JN`#%:KP]_^78/[_-/,#&ZHA`(!2VO__%R$`@%+@`Q:JW??_EX#]
M_S7A`Q:J````T`!@$9'$_?^7X`,6JKKW_Y>V%T#YN.=#J;KO1*F8__\7N!]`
M^;HG0/F0__\7MA<`^;CG`ZFZ[P2IM_?_EP$`0#GB`P"JX0``-!\@`]4`!`"1
M/[P`<4(0@)H!`$`Y@?__->`#`JK``U_6'R`#U4`(`+3]>[ZI_0,`D?-3`:GS
M`P"J%`!`.?0"`#0O]_^7``0`T6("`(M_`@+KH@,`5&!J8#@?O`!QH```5!8`
M`!1``$`Y'[P`<6$"`%1"!`#1?P("ZV'__U2?O@!QP```5/-30:D```"P_7O"
MJ`#`$9&&]_\7\U-!J0```+#]>\*H`$`/D8'W_Q=``$`Y'[P`<:`!`%1"!`#1
M?P("ZV/__U1_`@+KH/W_5$($`-%_`@+K`@$`5!\@`]5``$`Y'[P`<8$``%1"
M!`#1?P("ZV/__U1"`!/+0`@`D1\$0/'(`0!4I```T(2@`I$#`(+20@0`D>$#
M$ZK@`P2J-/?_E_-30:G]>\*HP`-?U@```+``0`^17O?_%P``@-+Y__\7'R`#
MU?U[N*D!``"P(6`.D0```+#]`P"1\U,!J;,``+#U6P*I```2D6/B1_D6``"P
M]V,#J1<``+`F'$&I8@!`^:(_`/D"`(#2)!1"J:8?!:DA8$!Y&```L*07!JD4
M``"PH>,`>92"$Y&U,P&1'OW_EP```+``0!*1&_W_EP```+``8!*1&/W_EP``
M`+``H!*1%?W_E\#"$I$3_?^7````L```$Y$0_?^7X"(1D0[]_Y<`0Q.1#/W_
ME^`#%*H*_?^7````L`#`$Y$'_?^7````L`!@$9$$_?^7````L.$#%:H``!21
MO/S_EX```+3A`P"JX`,4JB;]_Y<```"PX0,5J@!@%)&T_/^7H```M`(``+#A
M`P"J0,`4D1W]_Y<```"PX0,5J@``%9&K_/^70`(`M.$#`*K@(A&1%?W_EP$`
M`+#`PA*1(>`5D1']_Y=SXD?YH3]`^6`"0/D@``#*0`,`M?-30:GU6T*I]V-#
MJ?U[R*C``U_6````L.$#%:H`0!61E?S_EX`!`+4!``"PM$,!D4(!@-(AH!61
MH(<!D=#V_Y?@_/\U@6X`D0!#$Y'X_/^7X___%^$#`*H`0Q.1]/S_E]___Q?R
M]O^7'R`#U?U[O:G]`P"1\U,!J;,``+"T``#08>)'^8`20+DB`$#YHA<`^0(`
M@-(?!``Q(`$`5'/B1_FB%T#Y80)`^4$``<HA`@"U\U-!J?U[PZC``U_6H9,`
MD0```+``0!.1:_S_E^$#`*H``(!2H0``M"``0#D?P`!Q!!A`>N`'GQJ`$@"Y
M[/__%\_V_Y?]>[^I_0,`D7#V_Y?O]O^7@```M```0/G]>\&HP`-?U@``@-+]
M__\7_7N[J?T#`)'S"P#YLP``L/5;`JD5``"P]QL`^;<"%I%BXD?Y]@,`JJ$3
M`9'@`Q>J0P!`^:,G`/D#`(#21_S_EV`!`+2T#P#Y]`,`J@$`0#G!```TX0,6
MJA[W_Y<@`@"TM`]`^04``!2T#T#YX0,6JJ`"%I&G_/^7<^)'^:$G0/E@`D#Y
M(```RJ`#`+7S"T#Y]5M"J?<;0/G]>\6HP`-?UN`#%JHG]O^7]0,`JN`#%*HD
M]O^7H`(`BP`(`)%9]O^7Y@,4JN0#%JH%``"P`P``L*6@$9%CX!&1`@"`DO4#
M`*HA`(!2&_;_E^$#%:K@`Q>JB/S_E[0/0/G@__\7M`\`^83V_Y<?(`/5$#J0
MTO]C,,NJ``#02D$`D0L$D-+]>P&I_4,`D:T#"XM$E4"I]5L#J;8``+#S$P#Y
M^"<`^?@#`*KZ+P#YM3,"D<SB1_D:``"P2PU`^4`%0JF.`4#YKLT`^0X`@-)&
M'4.II!<)J4@E1*FK4P#Y0@U%J:*/"JE*,4#YJE\`^:`'#*GA`Q6JIA\-J4`C
M$9&H)PZI\/O_EX```+0!`$`Y\P,`JL$1`#6T#P#YMQL`^;DC`/F[*P#YA___
ME_0#`*J`$0"TX`,4JMWU_Y<`^'_3``0`D1+V_Y>$`D`Y]P,`JJ0!`#0```"P
M\P,7JAE@%I$?(`/5X`,3JN,#&:H"`("2(0"`4M+U_Y=S"@"1A!Y`."3__S6@
M8T#YP`L`M+D#`Y$S`(#2!0``%',&`)$@#Q.+`(!?^.`*`+3A`Q6JQOO_E_0#
M`*H@__^T`0!`.>'^_S0C_?^7H/[_-.`#%*HD]O^7^P,`JF`)`+0?(`/5X`,;
MJK/U_Y?S`P"JX`,7JK#U_Y<3`!,+<Q(0$1D``+!S?D"3X`,3JN+U_Y?G`Q>J
M)<,1D>0#&ZH&``"P`P``L,:`%I%CH!:1`@"`DO0#`*HA`(!2H_7_EP$X@%+@
M`Q2JC/;_EQ\$`#&A``!4@?;_EP4`0+F_1`!QH1@`5+?#`Y&\+P#YX0,4JN(#
M%ZH``(!2//;_E_P#`"J@```UH`-!N0`,%!(?$$!QX`D`5*```+`#`T#YY`,4
MJ@(``+``S$?Y0N`7D2$`@%(3`(#2``!`^1#V_Y>T#T#YMQM`^;DC0/F[<T6I
M`020TM;B1_FA`P&+X`,3JB+,0/G!`D#Y00`!RD$X`+7]>T&I$#J0TO,30/GU
M6T.I^"=`^?HO0/G_8S"+P`-?UKE#`I$4`(!2'R`#U3/;=/BS`0"T8`)`.6`!
M`#3@`Q.JE`8`$<K\_Y<@__\TX`,3JLOU_Y?[`P"J(/7_M3/;=/BS_O^U&P"`
MTJ7__Q<(__^7X`,3JL+U_Y?S`P"JV?__%[>C`I$3`(!2'R`#U>#:<_B@`0"T
MX0,5JG,&`!%2^_^78/__M`$`0#DA__\TM/7_E_0#`*H`[?^UX-IS^,#^_[4?
M(`/5H`&`TGGU_Y<4``"P]P,`JF0*@%*40A:19O__%[L+0;E2]?^7?P,`:^'U
M_U2@`T&Y`"``$A\`!W%A]?]4X`,3JFKU_Y?A`Q6J\P,`J@```+``0!F1,_O_
MET`-`+05`T#YEO7_E^$#`*K@`Q6J6?W_E_4#`*I@#`"TX`,5JB/U_Y?[`P"J
M'PP`<0T"`%0`?$"3`0``L``0`-$A8!F1H`(`BZ[U_Y<@`0`U?Q,`<:`E`%1@
M$P!1H,(@BP#P7S@?O`!Q`"4`5!\@`]64_O^7P```-0$`@%+@`Q6JY/7_EZ!W
M`+E`"0`U`0``L"'@%9$```"P`$`3D7G[_Y<YPQ&1-_7_EQ4``+"U(AV1Y@,`
M*@,``+#G`Q6JY0,9JN0#%*ICX!F1`@"`DB$`@%+@`Q.J%P``L/@#&:KY]/^7
M]R(:D1$``!3:]?^7``!`N1]$`'%!`@!4(O7_E_4#`/F<!P`1Y@,`*N<#'"KE
M`QBJY`,4JN,#%ZH"`("2(0"`4N`#$ZKG]/^7`3B`4N`#$ZK0]?^7'P0`,8#]
M_U3@`Q2JC/7_E^$#$ZI`(Q&13?O_E^`#$ZJ'_O^7M`]`^;<;0/FY(T#YNW-%
MJ5?__Q>@``"P`P-`^>0#%*H"``"P`,Q'^4+@%I$A`(!2$P"`T@``0/E8]?^7
MM`]`^;<;0/FY(T#YNRM`^4C__Q<5`T#YG?__%Z/C!I%"`(!2]0,#JB$"@)*C
M/P#Y%_7_EZ!W0+G"`(#2X0,5JH?U_Y>@XT8Y@```-:#G1CD?#`%QH!P`5*!W
M0+D"`(!2`0"`TKRC!)$)]?^7O_\1J>#B`)$D8(32(W&5TL*?F]+!CHK2H#<`
M^0`^G-*DZ*SRH_F]\D(7L_)!!J+R0'JX\J0/#ZFB!Q"IH(L`^;]K`;F@=T"Y
M`@"0TJ$_0/EH]?^7XP,`JO4#`"H?``!QK0@`5*6+4:EA?$"3H&M!N:0,`0N_
M``3K0I2"FD%T08NDAQ&IX!,`-`$(@%(U``!+?P`5:Z$_0/EUT)4:HC=`^:,S
M`/F[?D"30,`@B^(#&ZIT]/^7H&M!N:,S0/F@`@`+H&L!N1\``7'A^_]4H#]`
M^74`%4L;`!N+X`,7JCWV_Y>__@!QS0(`5+4"`5&@?@93H&,`N1AD&E,8`P&1
M>`,8BV070*F$%P"I8@]!J8(/`:E@!T*I@`<"J68?0ZF&'P.I>P,!D>`#%ZHJ
M]O^7'P,;ZX'^_U2@8T"YM1H`2Z`W0/D#"8#2HGY`D^$#&ZJ)]/^7M6L!N:!W
M0+D"`)#2H3]`^23U_Y?C`P"J]0,`*A\``'&L]_]4H'=`N<;T_Y>UXU&IX@^`
M$J$B`U,@!``1'^``<8++(3AL#0!4X^(`D0('@%)"``!+`0"`4F#`((M"?$"3
MD/3_EP'_6-,`_U#3H8,%.:'^6-.@AP4Y`/](TZ"+!3F@_E#3H)<%.:#^2-.X
MCP4YO",&D:&3!3FXQP61H)L%.>`#%ZJUGP4Y]O7_EZ873ZD```"PHPM0J1=@
M%I&ABT#YR/Q0T\?\2-.@_%C3J?Q0TZC'!3FGRP4YJ/Q(TV?\6-.@TP4Y8/Q(
MT\1\&%.FSP4Y:OQ0TZ3#!3DF_%C3J=<%.?4#'*JHVP4Y2?Q8TTC\4-.EWP4Y
MI^,%.27\4--'_$C3JN<%.:#K!3F;HP"1(/Q(TZ/O!3FI\P4YJ/<%.:?[!3FB
M_P4YI@,&.:4'!CF@"P8YH0\&.0(``!0$%T`XX`,5JN,#%ZH"`("2(0"`4K4*
M`)$`]/^7?P,5ZP'__U0'``"PY@,<JN<@'9$#``"PO\,&.27#$9'D`Q2J8Z`9
MD0(`@)(A`(!2X`,3JO+S_Y<0__\7NS]`^7?__Q<8!T#Y.-O_M.`#&*KG\_^7
M'PP`\:G:_U0`$`#1`0``L``#`(LA@!F1=/3_EQ\``'&U$IB:S?[_%P((@%)"
M``!+`0"`4OOB`)%"?$"38,,@BR;T_Y?@`Q>JG/7_EZ"#")$?_#"I__X$J?_^
M!:G_-@#YC___%Z#K1CD?!`%Q0>/_5*#O1CD?#`%QX>+_5*#S1CD?(`%Q@>+_
M5*#W1CD?%`%Q(>+_5+=W0+E"`(!2(0>`DN`#%RH9]/^7M3]`^2(%@-+@`Q<J
MX0,5JHCT_Y<'``"PY@,5J@,``+#G(!V1O___%[0/`/FW&P#YN2,`^;MS!:DB
M]/^7'R`#U?U[N*F@``"P_0,`D?<;`/FW``"P\U,!J?/61_GU6P*IM=,!D?HG
M`/D`X$?YM3,`^0$`0/FA/P#Y`0"`TF`"0+D`]/^7]`,`JF`"0+G]\_^7@>)"
M.0'D`CD```"PX0,5J@#`$I&9^?^7@```M`$`0#D_Q`!QX!,`5*#\_Y?VUD?Y
MP`)`N>_S_Y<!``"P8P&`4B(`@%(A@!J1`O3_EZ`5`+2X'P#YH0``T#4@`I&A
M-P#Y`0A`^=H"0+F@!D"Y.!1`^1\$`'$M&0!4N2,`^1F`@%*[<P6I%`"`4C,`
M@%(9!*!R"@``%&$(0/G@`QRJ!?3_EZ$&0+D@!``U<P8`$90&`!$_`!-KK0,`
M5.`#&BK-\_^7`P"`4H)^0)/A`QBJ,?3_E_L#`*H@$P"T`P!`^:0&0/G:`D"Y
M8`Q`N9S8<_@``!D*'P`0<0#]_U3@`QHJO?/_EV$#0/E#`(!2`@"`TJGS_Y?A
M`P"JX`,<JN;S_Y?:`D"YH09`N2#\_S0@!`!1'P`4:^`+`%2XYT.INW-%J>`#
M&BJL\_^78P"`4@$``+`B`(!2(:`:D;_S_Y?S`P"JH`$`M/361_F``D"YHO/_
MEV$*0/D"``"00L`:D2$`0/E]\_^78`I`^0``0/D`#$"YH`^P-_361_F``D"Y
MEO/_EP$``)!C`(!2(@"`4B'@&I&I\_^7\P,`JJ`!`+2A,T#Y````D`!@$9$M
M^?^7]0,`JH`"0+EU#`"TA_/_EV$*0/GB`Q6J(0!`^6/S_Y?WUD?YH#=`^10@
M`I'@`D"Y?O/_E_,#`*K@`D"Y>_/_ER(`@%(!``"0(0`;D;/S_Y<"``"0X0,`
MJD)@&Y'@`Q.J4O/_E^`"0+EP\_^7'^0".:$S0/D```"0`"`1D0WY_Y>`"@#Y
M\P,`J@`&`+0!.(!2X`,3JO'S_Y<!!``1/P0`<02(47H!"@!4H```D!K@1_FA
M/T#Y0`-`^2```,K@"`"U\U-!J?5;0JGW&T#Y^B=`^?U[R*C``U_6``1`.4#L
M_S1@__\7/P0`<2WT_U2@-T#Y,P"`4O761_D4(`*1`@``%+H"0+G@`QHJ2//_
ME^$#&*H"\_^7@`9`N7,&`!$?`!-K#/__5.#61_FXYT.INW-%J1H`0+F0__\7
MH```L-H"0+F@-P#YC/__%X`&0/G%_/^7@`H`^?,#`*J@^?^U````D+CG`ZF[
M<P6I`(`;D6_S_Y>A-T#YX-9'^2$@`I$A!$"Y&@!`N2`$`%$?`!1K`>__5-7_
M_Q<E\_^7H#=`^6(*0/D`(`*1`01`^4``0/DA`$#Y2/K_EYO__Q>``D"Y&_/_
MEV$*0/DA`$#Y<//_EW___Q>X'T#Y:/__%[CG`ZF[<P6I(O/_EZ$W0/GC`P`J
MNW,%J>(#$ZH\(`*1N.<#J0$``)`@(!R1@0=`^2$`0/E'\_^7_7N^J?T#`)'S
M4P&I]`,`JFC[_Y<!`$`Y\P,`JL$``#0`!`"1/[P`<7,2@)H!`$`Y@?__-1G\
M_Y>?`@#Q!!A`>H$``%3S4T&I_7O"J,`#7]:``D`Y@/__-`$``)""`(#2(8`6
MD>`#$ZK0\O^7P/[_->`#%*KS4T&I_7O"J(?Y_Q>C``"P8P1`^:3R_Q<`````
M_7N\J?T#`)'TUP&IM```D+4``)"4XBR1M<(LD?;?`JF4`A7+^!\`^?8#`"KW
M`P&JE/Y#D_@#`JI6\O^7E`$`M+,+`/D3`(#2HWIS^.(#&*KA`Q>JX`,6*G,&
M`)%@`#_6GP(3ZR'__U2S"T#Y]-=!J?;?0JGX'T#Y_7O$J,`#7];``U_6_7N_
MJ?T#`)']>\&HP`-?U@`````!``(``````'!E<FQX<VDN8P````````!?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````+@`````````N
M+@```````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````97AE
M```````O<')O8R\E:2\E<P``````4$%27U1%35```````````%!!4E]04D]'
M3D%-10`````Z`````````"\`````````)7,E<R5S``!015),-4Q)0@``````
M````4$523$Q)0@!015),-4]05```````````4$523$E/``!005)?24Y)5$E!
M3$E:140`4$%27U-005=.140``````%!!4E]#3$5!3@````````!005)?1$5"
M54<`````````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<`````
M`````%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$25(```````!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````4$%27T-,
M14%./0```````#$`````````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R
M>`````!P87(M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``````
M`%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S
M=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````05)'5@`````8
M`````````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@``
M```Q+C`T-0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y````
M```````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````E<P```````"UE````
M````+2T```````!54T52`````%5315).04U%``````````!435!$25(``%1%
M35!$25(`5$5-4`````!435```````"]T;7``````979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G
M"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP
M+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP
M.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF
M:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@
M-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ
M92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O
M<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@
M)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@
M)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL
M87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S
M970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@
M)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O
M9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S
M970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T
M.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I
M;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U
M-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA
M;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY
M("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N
M;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@
M<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M
M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP
M;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL
M96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM
M;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N
M;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I
M92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@
M82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V
M86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD
M968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E
M7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@
M)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N
M86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA
M;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?
M.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI
M('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H
M;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T
M96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG
M("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N
M+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F
M:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)
M3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF
M("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX
M?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N
M(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P
M<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N
M86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C
M='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C
M:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M
M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z
M("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T
M<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*
M*%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R
M;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K
M("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@
M<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L
M(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%2
M7T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\[
M"FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE
M("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*
M;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I
M=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O
M;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@
M9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O
M<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U
M8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G
M;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]4
M14U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@
M,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R
M;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R
M7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.
M?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS
M=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I
M;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*
M<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL
M:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O
M<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?
M14Y$7U\*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````()```````
M`,`C`````````0`````````!``````````$`````````RP$````````!````
M`````!H"`````````0````````!S`P````````P`````````B!P````````-
M`````````'Q3````````&0`````````PFP$``````!L`````````"```````
M```:`````````#B;`0``````'``````````(`````````/7^_V\`````8`(`
M```````%`````````*`-````````!@````````!0`P````````H`````````
M\@0````````+`````````!@`````````%0````````````````````,`````
M````8)T!```````"```````````&````````%``````````'`````````!<`
M````````B!8````````'`````````-`3````````"`````````"X`@``````
M``D`````````&``````````>``````````@`````````^___;P`````!```(
M`````/[__V\`````<!,```````#___]O``````,`````````\/__;P````"2
M$@```````/G__V\`````$```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````*`<````````
MH!P```````"@'````````*`<````````H!P```````"@'````````*`<````
M````H!P```````"@'````````*`<````````H!P```````"@'````````*`<
M````````H!P```````"@'````````*`<````````H!P```````"@'```````
M`*`<````````H!P```````"@'````````*`<````````H!P```````"@'```
M`````*`<````````H!P```````"@'````````*`<````````H!P```````"@
M'````````*`<````````H!P```````"@'````````*`<````````H!P`````
M``"@'````````*`<````````H!P```````"@'````````*`<````````H!P`
M``````"@'````````*`<````````H!P```````"@'````````*`<````````
MH!P```````"@'````````*`<````````H!P```````"@'````````*`<````
M````H!P```````"@'````````*`<````````H!P```````"@'````````*`<
M````````H!P```````"@'````````*`<````````H!P```````"@'```````
M`*`<````````0)L!``````!X4P``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````/A2``````````````````#`(```````````````````````````
M````````````````````````"*`!``````#_____`````*!7````````T%,`
M`````````````````#!5````````@%<```````"(5P```````)!7````````
MF%<``````````````````&A7````````<%<``````````````````*A7````
M````1T-#.B`H56)U;G1U+TQI;F%R;R`W+C,N,"TR,W5B=6YT=3(I(#<N,RXP
M`$=#0SH@*%5B=6YT=2],:6YA<F\@-RXS+C`M,39U8G5N='4S*2`W+C,N,```
M+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I
M;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`
M+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X
M=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A
M<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@```````````@`````````"
M````````&P````````````````````$````````````````````3````!P``
M``(`````````'`(````````<`@```````"`````````````````````$````
M````````````````(0````<````"`````````#P"````````/`(````````D
M````````````````````!````````````````````#0```#V__]O`@``````
M``!@`@```````&`"````````[``````````%``````````@`````````````
M```````^````"P````(`````````4`,```````!0`P```````%`*````````
M!@````,````(`````````!@`````````1@````,````"`````````*`-````
M````H`T```````#R!````````````````````0```````````````````$X`
M``#___]O`@````````"2$@```````)(2````````W``````````%````````
M``(``````````@````````!;````_O__;P(`````````<!,```````!P$P``
M`````&``````````!@````,````(````````````````````:@````0````"
M`````````-`3````````T!,```````"X`@````````4`````````"```````
M```8`````````'0````$````0@````````"(%@```````(@6``````````8`
M```````%````%`````@`````````&`````````!^`````0````8`````````
MB!P```````"('````````!0````````````````````$````````````````
M````>0````$````&`````````*`<````````H!P````````@!```````````
M````````$``````````0`````````(0````!````!@````````#`(```````
M`,`@````````O#(```````````````````@```````````````````"*````
M`0````8`````````?%,```````!\4P```````!`````````````````````$
M````````````````````D`````$````"`````````)!3````````D%,`````
M``!00```````````````````"````````````````````)@````!`````@``
M``````#@DP```````."3````````!`````````````````````0`````````
M``````````"B````#@````,`````````,)L!```````PFP````````@`````
M```````````````(``````````@`````````K@````\````#`````````#B;
M`0``````.)L````````(````````````````````"``````````(````````
M`+H````&`````P````````!`FP$``````$";````````(`(````````&````
M``````@`````````$`````````##`````0````,`````````8)T!``````!@
MG0```````*`"```````````````````(``````````@`````````R`````$`
M```#``````````"@`0```````*````````"`````````````````````"```
M`````````````````,X````(`````P````````"`H`$``````("@````````
M*!````````````````````@```````````````````#3`````0```#``````
M``````````````"`H````````%8````````````````````!``````````$`
M`````````0````,`````````````````````````UJ````````#<````````
9`````````````0``````````````````````
